@@ -2,7 +2,7 @@ import json
 from typing import Dict
 from inspect import isclass
 
-__version__ = '0.6.7'
+__version__ = '0.6.8'
 
 renderers: Dict = {}
 
@@ -18,17 +18,17 @@ class BaseNode:
 
     def is_renderable(self, node):
         """
-        Suggests if the node is worth rendering. 
-        Example: Image block without src attribute might not. 
-        This doesn't affect node rendering however can be considered
-        by high level functions such as convert_any here
+        Checks whether the node is worth rendering.
+        Example: Image block without src attribute might not.
         """
         return True
 
     def render(self, in_data) -> str:
-        out = self.inner_render(in_data)
-        if self.wrap_tag:
-            return f"<{self.wrap_tag}>{out}</{self.wrap_tag}>"
+        out = ''
+        if self.is_renderable(in_data):
+            out = self.inner_render(in_data)
+            if self.wrap_tag:
+                out = f"<{self.wrap_tag}>{out}</{self.wrap_tag}>"
         return out
 
     def inner_render(self, node) -> str:
@@ -112,7 +112,7 @@ class Embed(BaseContainer):
         attrs = node['attrs']
         html = attrs.get('html', '')
         if attrs.get('type') == 'video':
-            caption = attrs.get('caption', '').strip()
+            caption = (attrs.get('caption') or '').strip()
             if caption:
                 html += f"<figcaption>{caption}</figcaption>"
         provider_name = attrs.get('provider') or 'link'
@@ -179,9 +179,7 @@ for o in tuple(locals().values()):
 def convert_any(in_data):
     typ = in_data.get("type")
     renderer = renderers.get(typ)
-    if renderer.is_renderable(in_data):
-        return renderer.render(in_data)
-    return ''
+    return renderer.render(in_data)
 
 
 def to_html(s):
